"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("../errors");
class Emitter {
    constructor(source) {
        this.events = new Map();
        this.silent = false;
        this.events = source instanceof Emitter ? source.events : source.handlers;
    }
    on(eventNames, handler) {
        const events = Array.isArray(eventNames) ? eventNames : eventNames.split(' ');
        events.forEach(eventName => {
            const event = this.events.get(eventName);
            if (!event) {
                throw new Error(errors_1.EngineError.EventNameUndefined + eventName);
            }
            event.push(handler);
        });
        return this;
    }
    trigger(eventName, params = {}) {
        const event = this.events.get(eventName);
        if (!event) {
            throw new Error(errors_1.EngineError.EventTriggerFailed + eventName);
        }
        return event.reduce((accumulator, handler) => handler(params) !== false && accumulator, true);
    }
    bind(eventName) {
        if (this.events.get(eventName)) {
            throw new Error(errors_1.EngineError.EventAlreadyBound + eventName);
        }
        this.events.set(eventName, []);
    }
    exist(eventName) {
        return Array.isArray(this.events.get(eventName));
    }
}
exports.Emitter = Emitter;
//# sourceMappingURL=emitter.js.map