"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const io_1 = require("./io");
const connection_1 = require("./connection");
const errors_1 = require("./errors");
class Output extends io_1.IO {
    constructor(key, name, socket, allowMultipleConnections = true) {
        super(key, name, socket, allowMultipleConnections);
    }
    connectTo(input) {
        if (!this.socket.compatibleWith(input.socket)) {
            throw new Error(errors_1.EngineError.SocketsNotCompatible);
        }
        if (!input.allowMultipleConnections && input.hasConnection()) {
            throw new Error(errors_1.EngineError.InputHasConnection);
        }
        if (!this.allowMultipleConnections && this.hasConnection()) {
            throw new Error(errors_1.EngineError.OutputHasConnection);
        }
        const connection = new connection_1.Connection(input, this);
        this.connections.push(connection);
        return connection;
    }
    connectedTo(input) {
        return this.connections.some(item => item.input === input);
    }
    toJSON() {
        return {
            'connections': this.connections.map(({ input, data }) => {
                if (!input.node) {
                    throw new Error(errors_1.EngineError.NodeNotFoundForInput + input.key);
                }
                return {
                    nodeId: input.node.id,
                    inputKey: input.key,
                    data,
                };
            }),
        };
    }
}
exports.Output = Output;
//# sourceMappingURL=output.js.map